<?php

namespace Drupal\consistent_breadcrumbs;

use Drupal\Core\Cache\RefinableCacheableDependencyInterface;
use Drupal\Core\Routing\RouteMatchInterface;

interface ConsistentBreadcrumbBuilderInterface {

  /**
   * Get next breadcrumb slice.
   *
   * @param \Drupal\Core\Routing\RouteMatchInterface $routeMatch
   *   The route match to get next breadcrumb for.
   * @param bool|null $isFinalSlice
   *   Last slice info, returned by reference. You can (and usually) want to
   *   ignore this, in which case the manager checks if the last link of the
   *   returned breadcrumb slice is '<front>'. If you want a different behavior,
   *   set this accordingly.
   *
   * @return \Drupal\Core\Breadcrumb\Breadcrumb
   *   The next breadcrumb links, if applicable, or a Breadcrumb object with an
   *   empty links array otherwise. Care to add cacheability in any case, as any
   *   following builder's breadcrumbs depend on your breadcrumbs not matching.
   *   You do not need to check link access, as this is done by the manager, and
   *   any slice with a non-access link is discarded.
   *   You can (and usually want) to set the link text to '', in which case it
   *   is replaced by the default route title.
   */
  public function getBreadcrumbSlice(RouteMatchInterface $routeMatch,  &$isFinalSlice = NULL);

}
